pkglts\.option\.requires package
================================

Submodules
----------

pkglts\.option\.requires\.config module
---------------------------------------

.. automodule:: pkglts.option.requires.config
    :members:
    :undoc-members:
    :show-inheritance:

pkglts\.option\.requires\.handlers module
-----------------------------------------

.. automodule:: pkglts.option.requires.handlers
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pkglts.option.requires
    :members:
    :undoc-members:
    :show-inheritance:
